<a href="http://mypy-lang.org/">
<img src="http://mypy-lang.org/static/mypy_light.svg" alt="mypy logo" width="300px"/>
</a>

# Typing stubs for Pika library

This package contains [type stubs](https://www.python.org/dev/peps/pep-0561/) to provide more precise static types and type inference for [pika](https://github.com/pika/pika), the RabbitMQ client library.


## Installation

```bash
pip install types-pika
```

That's all, run Mypy and it should be able to pick up these stubs.
